==> ejc-lz-impl-3.0.0-20220421.012039-57-sources.jar: com/ejianc/business/base/vo/ProductCategoryVO.java <==
package com.ejianc.business.base.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 产品类别
 * 
 * @author generator
 * 
 */
public class ProductCategoryVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long parentId; // 父ID
    private String code; // 编码
    private String name; // 类别名称
    private String unitName; // 
    private Integer enabled; // 1:启用/0:停用
    private String description; // 描述
    private Integer sequence; // 排序
    private Integer systemId; // 来源系统id
    

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public Integer getEnabled() {
        return enabled;
    }

    public void setEnabled(Integer enabled) {
        this.enabled = enabled;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
    public Integer getSequence() {
        return sequence;
    }

    public void setSequence(Integer sequence) {
        this.sequence = sequence;
    }
    public Integer getSystemId() {
        return systemId;
    }

    public void setSystemId(Integer systemId) {
        this.systemId = systemId;
    }
    
}

==> ejc-lz-impl-3.0.0-20220526.021003-106-sources.jar: com/ejianc/business/base/vo/ProductCategoryVO.java <==
package com.ejianc.business.base.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 产品类别
 * 
 * @author generator
 * 
 */
public class ProductCategoryVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long parentId; // 父ID
    private String code; // 编码
    private String name; // 类别名称
    private String unitName; // 
    private Integer enabled; // 1:启用/0:停用
    private String description; // 描述
    private Integer sequence; // 排序
    private Integer systemId; // 来源系统id
    private String errorMsg;

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public Integer getEnabled() {
        return enabled;
    }

    public void setEnabled(Integer enabled) {
        this.enabled = enabled;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
    public Integer getSequence() {
        return sequence;
    }

    public void setSequence(Integer sequence) {
        this.sequence = sequence;
    }
    public Integer getSystemId() {
        return systemId;
    }

    public void setSystemId(Integer systemId) {
        this.systemId = systemId;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }
}
